/*
    SpecRunner - Acceptance Test Driven Development Tool
    Copyright (C) 2011-2013  Thiago Santos

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */
package org.specrunner.sql;

import javax.sql.DataSource;

/**
 * To perform a script a DataSource should be provided. Implement this interface
 * and add it to the specification as
 * <code>class="connection" provider='&lt;your class name&gt;'</code>.
 * 
 * @author Thiago Santos
 * 
 */
public interface IDataSourceProvider {

    /**
     * Returns the data source target for scripts execution.
     * 
     * @return The data source.
     */
    DataSource getDataSource();

    /**
     * Release data source resources.
     */
    void release();
}